@@ -42,18 +42,14 @@ class DefaultSettings(object):
 SETTINGS = DefaultSettings()
 
 
-try:  # Python 2.7+
-    from logging import NullHandler
-except ImportError:
-
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
 
 
 logging.getLogger(__name__).addHandler(NullHandler())
 
-__version__ = "0.21.0"
+__version__ = "0.22.0"
 
 __all__ = [
     "BadIngredient",
