@@ -1,8 +1,7 @@
 """Convert parsed trees into SQLAlchemy objects """
-from lark import Lark, Transformer, v_args
-from sqlalchemy import func, distinct, case, and_, or_, not_, cast, Float
+from lark import Transformer, v_args
+from sqlalchemy import func, case, and_, or_, not_, cast, Float
 from datetime import date
-from dateutil.relativedelta import relativedelta
 
 from .field_grammar import (
     field_parser,
@@ -11,13 +10,13 @@ from .field_grammar import (
     full_condition_parser,
 )
 from .utils import (
-    aggregations,
-    conversions,
+    generate_lookup_by_engine,
     find_column,
     ingredient_class_for_name,
     convert_value,
     calc_date_range,
 )
+from .engine_support import aggregations_by_engine, conversions_by_engine
 from recipe.exceptions import BadIngredient
 from recipe.ingredients import InvalidIngredient
 
@@ -26,11 +25,25 @@ from recipe.ingredients import InvalidIngredient
 class TransformToSQLAlchemyExpression(Transformer):
     """Converts a field to a SQLAlchemy expression """
 
+    # We have rules named "add", "sub", "mul", and "neg" in our grammar; Transformer
+    # dispatches to these.
     from operator import add, sub, mul, neg
 
     def __init__(self, selectable, require_aggregation=False):
         self.selectable = selectable
         self.require_aggregation = require_aggregation
+        # Database driver
+        try:
+            self.drivername = selectable.metadata.bind.url.drivername
+        except Exception:
+            self.drivername = "unknown"
+
+        self.aggregations = generate_lookup_by_engine(
+            aggregations_by_engine, self.drivername
+        )
+        self.conversions = generate_lookup_by_engine(
+            conversions_by_engine, self.drivername
+        )
 
     def number(self, value):
         try:
@@ -60,7 +73,18 @@ class TransformToSQLAlchemyExpression(Transformer):
         return "BETWEEN"
 
     def aggregate(self, name):
-        return aggregations.get(name.lower())
+        """Return a callable that generates SQLAlchemy to aggregate a field.
+
+        Aggregations may be database specific
+        """
+        ag = self.aggregations.get(name.lower())
+        if ag is None:
+            raise ValueError(
+                "Aggregation {} is not supported on {} engine".format(
+                    name, self.drivername
+                )
+            )
+        return ag
 
     def div(self, num, denom):
         """SQL safe division"""
@@ -89,10 +113,23 @@ class TransformToSQLAlchemyExpression(Transformer):
             return aggr(val)
 
     def conversion(self, name):
-        return conversions.get(name.lower())
+        conv_fn = self.conversions.get(name.lower())
+        if conv_fn is None:
+            raise ValueError(
+                "Conversion {} is not supported on {} engine".format(
+                    conv_fn, self.drivername
+                )
+            )
+        return conv_fn
 
     def convertedcol(self, conversion, col):
-        conv_fn = conversions.get(conversion.lower())
+        conv_fn = self.conversions.get(conversion.lower())
+        if conv_fn is None:
+            raise ValueError(
+                "Conversion {} is not supported on {} engine".format(
+                    conv_fn, self.drivername
+                )
+            )
         return conv_fn(col)
 
     def expr(self, expr):
@@ -114,11 +151,11 @@ class TransformToSQLAlchemyExpression(Transformer):
 
     def is_comparison(self, *args):
         """Things that can be compared with IS
-        
+
         will be either IS NULL or an intelligent date
         like "IS prior year" or "IS next week".
 
-        If intelligent dates are used, determine the relevant dates and 
+        If intelligent dates are used, determine the relevant dates and
         return a tuple of start_date, end_date
         """
         if len(args) == 1 and args[0] is None:
@@ -134,10 +171,10 @@ class TransformToSQLAlchemyExpression(Transformer):
         comparators = {
             "=": "__eq__",
             ">": "__gt__",
-            ">=": "__gte__",
+            ">=": "__ge__",
             "!=": "__ne__",
             "<": "__lt__",
-            "<=": "__lte__",
+            "<=": "__le__",
         }
         if right is None:
             return
@@ -194,12 +231,11 @@ def create_ingredient_from_parsed(ingr_dict, selectable):
     kind = ingr_dict.pop("kind", "metric")
     IngredientClass = ingredient_class_for_name(kind.title())
     if IngredientClass is None:
-        raise BadIngredient("Unknown ingredient kind")
+        raise BadIngredient(f"Unknown ingredient kind {kind}")
 
     if kind in ("metric", "dimension"):
         parser = field_parser if kind == "metric" else noag_field_parser
         fld_defn = ingr_dict.pop("field", None)
-        tree = parser.parse(fld_defn)
         # Create a sqlalchemy expression from 'field' and pass it as the first arg
         args = [
             TransformToSQLAlchemyExpression(selectable=selectable).transform(
@@ -247,5 +283,10 @@ def create_ingredient_from_parsed(ingr_dict, selectable):
     try:
         return IngredientClass(*args, **ingr_dict)
     except BadIngredient as e:
-        error = {"type": "bad_ingredient", "extra": {"details": str(e),}}
+        error = {
+            "type": "bad_ingredient",
+            "extra": {
+                "details": str(e),
+            },
+        }
         return InvalidIngredient(error=error)
